Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(12)

Unified Diff: net/quic/test_tools/crypto_test_utils.h

Issue 1904213002: QUIC: support diversified keys with version 33. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@hkdf
Patch Set: Rebase Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « net/quic/reliable_quic_stream_test.cc ('k') | net/quic/test_tools/crypto_test_utils.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: net/quic/test_tools/crypto_test_utils.h
diff --git a/net/quic/test_tools/crypto_test_utils.h b/net/quic/test_tools/crypto_test_utils.h
index c8beb6092a78c17d18d3328e11ecfb70cfd33879..39ed8384c733f23960c26b4cf1c8bb11ca17f228 100644
--- a/net/quic/test_tools/crypto_test_utils.h
+++ b/net/quic/test_tools/crypto_test_utils.h
@@ -110,34 +110,34 @@ class CryptoTestUtils {
QuicCryptoServerConfig* crypto_config,
const FakeServerOptions& options);
- // CommunicateHandshakeMessages moves messages from |a| to |b| and back until
- // |a|'s handshake has completed.
- static void CommunicateHandshakeMessages(PacketSavingConnection* a_conn,
- QuicCryptoStream* a,
- PacketSavingConnection* b_conn,
- QuicCryptoStream* b);
-
- // CommunicateHandshakeMessagesAndRunCallbacks moves messages from |a| to |b|
- // and back until |a|'s handshake has completed. If |callback_source| is not
- // nullptr, CommunicateHandshakeMessagesAndRunCallbacks also runs callbacks
- // from
+ // CommunicateHandshakeMessages moves messages from |client| to |server| and
+ // back until |clients|'s handshake has completed.
+ static void CommunicateHandshakeMessages(PacketSavingConnection* client_conn,
+ QuicCryptoStream* client,
+ PacketSavingConnection* server_conn,
+ QuicCryptoStream* server);
+
+ // CommunicateHandshakeMessagesAndRunCallbacks moves messages from |client|
+ // to |server| and back until |client|'s handshake has completed. If
+ // |callback_source| is not nullptr,
+ // CommunicateHandshakeMessagesAndRunCallbacks also runs callbacks from
// |callback_source| between processing messages.
static void CommunicateHandshakeMessagesAndRunCallbacks(
- PacketSavingConnection* a_conn,
- QuicCryptoStream* a,
- PacketSavingConnection* b_conn,
- QuicCryptoStream* b,
+ PacketSavingConnection* client_conn,
+ QuicCryptoStream* client,
+ PacketSavingConnection* server_conn,
+ QuicCryptoStream* server,
CallbackSource* callback_source);
// AdvanceHandshake attempts to moves messages from |a| to |b| and |b| to |a|.
// Returns the number of messages moved.
static std::pair<size_t, size_t> AdvanceHandshake(
- PacketSavingConnection* a_conn,
- QuicCryptoStream* a,
- size_t a_i,
- PacketSavingConnection* b_conn,
- QuicCryptoStream* b,
- size_t b_i);
+ PacketSavingConnection* client_conn,
+ QuicCryptoStream* client,
+ size_t client_i,
+ PacketSavingConnection* server_conn,
+ QuicCryptoStream* server,
+ size_t server_i);
// Returns the value for the tag |tag| in the tag value map of |message|.
static std::string GetValueForTag(const CryptoHandshakeMessage& message,
@@ -200,7 +200,8 @@ class CryptoTestUtils {
static void MovePackets(PacketSavingConnection* source_conn,
size_t* inout_packet_index,
QuicCryptoStream* dest_stream,
- PacketSavingConnection* dest_conn);
+ PacketSavingConnection* dest_conn,
+ Perspective dest_perspective);
private:
static void CompareClientAndServerKeys(QuicCryptoClientStream* client,
« no previous file with comments | « net/quic/reliable_quic_stream_test.cc ('k') | net/quic/test_tools/crypto_test_utils.cc » ('j') | no next file with comments »
@@ -110,34 +110,34 @@ class CryptoTestUtils {
CallbackSource* callback_source);
- // AdvanceHandshake attempts to moves messages from |a| to |b| and |b| to |a|.
- // Returns the number of messages moved.
+ // AdvanceHandshake attempts to moves messages from |client| to |server| and
+ // |server| to |client|. Returns the number of messages moved.
static std::pair<size_t, size_t> AdvanceHandshake(

Powered by Google App Engine
This is Rietveld 408576698